@@ -116,15 +116,18 @@ def random_id(n=12):
 def file_block_check(record_file, pre_time_point):
     current_datetime = datetime.now()
     while True:
-        with open(record_file, 'r') as file:
-            content = file.read()
-            update_time = datetime.strptime(content, '%Y-%m-%d %H:%M:%S')
-            print(f'当前时间：{current_datetime}，文件更新时间：{update_time},预测时间节点：{pre_time_point}')
-            if current_datetime > update_time > pre_time_point:
-                print(f'当前时间大于文件更新时间大于预测时间节点，开始预测')
-                break
-        time.sleep(1)
-        current_datetime = datetime.now()
+        try:
+            with open(record_file, 'r') as file:
+                content = file.read()
+                update_time = datetime.strptime(content, '%Y-%m-%d %H:%M:%S')
+                print(f'当前时间：{current_datetime}，文件更新时间：{update_time},预测时间节点：{pre_time_point}')
+                if current_datetime > update_time > pre_time_point:
+                    print(f'当前时间大于文件更新时间大于预测时间节点，开始预测')
+                    break
+            time.sleep(1)
+            current_datetime = datetime.now()
+        except:
+            logging.error(f'读取{record_file}文件失败')
 
 
 def find_path(file, dir):
